@@ -1,8 +1,7 @@
-from devtools import debug
-
 from sqla2uml.scanner import ClassInfo
 
-EXCLUDED = set()
+# Not used (to be refactored using a config file)
+EXCLUDED: set[ClassInfo] = set()
 
 
 class Generator:
